@@ -26,6 +26,7 @@ from torch.nn.utils import clip_grad_norm_
 from torch.nn.parallel.distributed import DistributedDataParallel as DDP
 from torch.cuda.amp import GradScaler
 from torch.utils.data import DataLoader, Dataset
+from torch.utils.data.distributed import DistributedSampler
 
 from dstk.pytorch._utils import check_tensor, is_dist_avail_and_initialized
 from dstk.pytorch._callback import (CallbackInterface, CallbackHandler,
@@ -584,7 +585,6 @@ class BaseEnvironnement(BaseEstimator):
         optimizer_kargs: Dict[str, any]=dict(),
         nb_epoch: int,
         iter_eval: Optional[int]=None,
-        eval_in_main_process: bool=True,
         callbacks: Optional[List[CallbackInterface]]=None,
         device: str='cuda:0',
         mixed_type_gpu: bool=False,
@@ -651,9 +651,6 @@ class BaseEnvironnement(BaseEstimator):
             défaut) les évaluations du modèle seront à la fin des époques. 
             Si un entier positif est renseigné les évaluations auront lieu 
             tous les iter_eval itérations d'apprentissage.
-        eval_in_main_process: bool (=True)
-            Exécute la phase d'évaluation dans le process principal dans le
-            cadre multi-GPU/multi-node.
         callbacks : Optional[List[CallbackInterface]]
             Liste de callback intervenant aux différentes étapes de 
             l'entraînement et de l'évaluation. Pour avoir la liste des 
@@ -760,31 +757,42 @@ class BaseEnvironnement(BaseEstimator):
             )
 
         if (
-            gradient_accumulation is not None and
-            iter_eval < gradient_accumulation
+            gradient_accumulation is not None
+            and iter_eval < gradient_accumulation
         ):
             warn(
                 "iter_eval < gradient_accumulation donc à chaque itération "
                 "un pas de gradient ne sera pas effectué."
             )
 
-        # marqueur permettant d'éxécuter la partir éval dans le processus
-        # principale ou partout (pour le cas multi-GPU/Node
-        if eval_in_main_process:
-            test_eval_prosses = is_main_process
-        else:
-            test_eval_prosses = lambda: True
-
-        if not (
-            eval_in_main_process
-            or eval_dataset is None
-            or hasattr(eval_dataset.sampler, 'set_epoch')
+        if (
+            is_dist_avail_and_initialized()
+            and not isinstance(X, DataLoader)
+            and not isinstance(X.sampler, DistributedSampler)
         ):
             raise AttributeError(
-                "Vous souhaitez réaliser l'éxécution du dataset en parallèle "
-                "mais il semblerait que le dataset ne soit pas compatible "
-                "pour la parallélisation (voir multi-GPU/multi-Note)."
+                "Vous être dans une instance parallélisé et le séquenceur "
+                "du dataset d'entraînement n'est pas de type "
+                "DistributedSampler !"
             )
+        elif (
+            not is_dist_avail_and_initialized()
+            and isinstance(X, DataLoader)
+            and isinstance(X.sampler, DistributedSampler)
+        ):
+            warn(
+                "La dataset d'entraînement possède un séquenceur prévu pour "
+                "du multi-node/muti-GPU. Il ce peut que ce soit un "
+                "comportement non souhaité."
+            )
+
+        if (
+            not eval_dataset is None
+            and isinstance(eval_dataset.sampler, DistributedSampler)
+        ):
+            test_eval_prosses = lambda: True
+        else:
+            test_eval_prosses = is_main_process
 
         # Permet de construire le modèle avec les paramètres actuels du fit.
         if build:
@@ -876,9 +884,9 @@ class BaseEnvironnement(BaseEstimator):
             filter(
                 lambda x: 
                     (
-                        x.lower() == 'state' or
-                        x.lower() == 'fitstate' or
-                        x.lower() == 'fit_state'
+                        x.lower() == 'state'
+                        or x.lower() == 'fitstate'
+                        or x.lower() == 'fit_state'
                     ),
                 co_varnames
             )
@@ -906,7 +914,10 @@ class BaseEnvironnement(BaseEstimator):
                     dataset.sampler.set_epoch(n_epoch)
                     if (
                         eval_dataset
-                        and hasattr(eval_dataset.sampler, 'set_epoch')
+                        and isinstance(
+                            eval_dataset.sampler, 
+                            DistributedSampler
+                        )
                     ):
                         eval_dataset.sampler.set_epoch(n_epoch)
                     torch.distributed.barrier()
@@ -959,17 +970,6 @@ class BaseEnvironnement(BaseEstimator):
                     control=control,
                     res_loss=loss_epoch
                 )
-                if eval_dataset and iter_eval is None:
-                    self._iter_eval(
-                        eval_dataset=eval_dataset,
-                        loss_fn=loss_fn,
-                        loss_kargs=loss_kargs,
-                        state=state,
-                        control=control,
-                        list_callbacks=list_callbacks
-                    )
-                if control.diverge or control.training_stop:
-                    break
         except (Exception, KeyboardInterrupt) as e:
             list_callbacks.error_interrupt(
                 model=self,
@@ -985,6 +985,7 @@ class BaseEnvironnement(BaseEstimator):
                     "------------------------------------------\n"
                     "| Fin du training par KeyboardInterrupt. |\n"
                     "------------------------------------------\n"
+                    "\n"
                 )
             else:
                 raise e
