@@ -9,7 +9,7 @@ Created on Sat Oct 22 14:50:47 2022
 """
 
 import os
-from typing import Optional, Dict, Any
+from typing import Optional, Dict, Any, Union
 from warnings import warn
 
 import torch
@@ -156,7 +156,16 @@ def auto_init_distributed(
     kwargs_eval_dataloader: Optional[Dict[str, Any]] = None,
     dist_url: str = "env://",
     backend: str = "nccl",
-    seed: int = 42
+    seed: int = 42,
+    output_device: Optional[Union[int, torch.device]] = None,
+    dim: int = 0,
+    broadcast_buffers: bool = True,
+    process_group: Optional[Any] = None,
+    bucket_cap_mb: int = 25,
+    find_unused_parameters: bool = False,
+    check_reduction: bool = False,
+    gradient_as_bucket_view: bool = False,
+    static_graph: bool = False
 ):
     r"""
     
@@ -186,6 +195,26 @@ def auto_init_distributed(
         Seed à destination du DistributedSampler afin de garantir que tous
         les processes aient la même seed pour le mélange (sinon les processes
         pourraient avoir des observations commune dans une eproch).
+    output_device: Optional[Union[int, torch.device]]
+        Voir doc DDP PyTorch `ici_`.
+    dim: int (=0)
+        Voir doc DDP PyTorch `ici_`.
+    broadcast_buffers: bool (=True)
+        Voir doc DDP PyTorch `ici_`.
+    process_group: Optional[Any]
+        Voir doc DDP PyTorch `ici_`.
+    bucket_cap_mb: int (=25)
+        Voir doc DDP PyTorch `ici_`.
+    find_unused_parameters: bool (=False)
+        Voir doc DDP PyTorch `ici_`.
+    check_reduction: bool (=False)
+        Voir doc DDP PyTorch `ici_`.
+    gradient_as_bucket_view: bool (=False)
+        Voir doc DDP PyTorch `ici_`.
+    static_graph: bool = False
+        Voir doc DDP PyTorch `ici_`.
+
+     .. _ici: https://pytorch.org/docs/stable/generated/torch.nn.parallel.DistributedDataParallel.html
 
     Notes
     -----
@@ -219,7 +248,16 @@ def auto_init_distributed(
     model = SyncBatchNorm.convert_sync_batchnorm(model)
     model = overload_distributed_data_parallel(model)(
         module=model,
-        device_ids=[local_rank]
+        device_ids=[local_rank],
+        output_device=None,
+        dim=dim,
+        broadcast_buffers=broadcast_buffers,
+        process_group=process_group,
+        bucket_cap_mb=bucket_cap_mb,
+        find_unused_parameters=find_unused_parameters,
+        check_reduction=check_reduction,
+        gradient_as_bucket_view=gradient_as_bucket_view,
+        static_graph=static_graph
     )
     shuffle = None
     drop_last = None
